package com.jakubu9333.grammarManager.api;

import com.jakubu9333.grammarManager.FileType;
import com.jakubu9333.grammarManager.service.FileService;
import com.jakubu9333.grammarManager.service.GrammarService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;

/**
 * @author Jakub Uhlarik
 */
@RestController
@CrossOrigin(origins = "http://localhost:3000")
@RequestMapping(path = "api/grammars")
public class GrammarController {


    private final GrammarService grammarService;



    @Autowired
    public GrammarController( GrammarService grammarService, FileService fileService) {
        this.grammarService = grammarService;

    }
    @PostMapping("")
    public ResponseEntity<String> grammarFromFile(@RequestBody String file, @RequestParam(required = false) String format) {
        if (format == null) {
            String uid = grammarService.addGrammarFromFile(file, null);
            return ResponseEntity.status(HttpStatus.CREATED).contentType(MediaType.TEXT_PLAIN).body(uid);
        }
        Boolean xml;
        switch (format) {
            case "jsgf" -> xml = false;

            case "xml" -> xml = true;
            case "u" -> xml = null;
            default -> throw new ResponseStatusException(HttpStatus.BAD_REQUEST, "invalid file format");
        }
        String uid = grammarService.addGrammarFromFile(file, xml);
        return ResponseEntity.status(HttpStatus.CREATED).contentType(MediaType.TEXT_PLAIN).body(uid);
    }



    @GetMapping("/root/{root}")
    public ResponseEntity<String> getGrammarXmlByRoot(@PathVariable String root) {
        return ResponseEntity.ok().contentType(MediaType.APPLICATION_XML).body(grammarService.getGrammarByRootSymbol(root));
    }

    @GetMapping("name/{name}")
    public ResponseEntity<String> getGrammarByJsgfName(@PathVariable String name){
        return ResponseEntity.ok().contentType(MediaType.TEXT_PLAIN).body(grammarService.getGrammarByJsgfName(name));
    }


    @GetMapping("/{uid}")
    public ResponseEntity<String> getGrammar(@PathVariable String uid, @RequestParam(defaultValue = "xml") String format) {
        FileType typeOfFile;
        switch (format.toLowerCase()) {
            case "xml" -> typeOfFile = FileType.XML_SRGS;
            case "jsgf" -> typeOfFile = FileType.JSGF;
            default -> throw new ResponseStatusException(HttpStatus.BAD_REQUEST, "invalid file format");
        }
        String result = grammarService.getGrammarByUid(uid,typeOfFile);
        return ResponseEntity.ok().contentType(typeOfFile == FileType.XML_SRGS ? MediaType.APPLICATION_XML : MediaType.TEXT_PLAIN).body(result);
    }

    @GetMapping("/uid")
    public ResponseEntity<String> getAllUid(){
        return ResponseEntity.ok().contentType(MediaType.APPLICATION_JSON).body(grammarService.getAllUid());
    }

}
