package com.jakubu9333.grammarManager;

import org.basex.BaseXServer;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.http.MediaType;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.web.servlet.MockMvc;

import static org.hamcrest.Matchers.is;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.content;
import static org.assertj.core.api.Assertions.assertThat;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

/**
 * @author Jakub Uhlarik
 */

@SpringBootTest
@AutoConfigureMockMvc
@ActiveProfiles("test")
public class IntegrationTests {

    @Autowired
    private MockMvc mockMvc;

    private final static String testXml2= """
                 <?xml version='1.0'?>
                 <grammar
                	xmlns="http://www.w3.org/2001/06/grammar" version="1.0" xml:base="xd" root="sde" xml:lang="en">
                	<rule id="p">
                		<one-of>
                			<item>d
                </item>
                			<item>pred
                				<ruleref uri="#xd"/>zad
                			</item>
                		</one-of>
                	</rule>
                	<rule id="sde">
                		<item> mam rad zvuk 
                			<ruleref uri="#mirozbirka"/>  zvuk jabloní
                		</item>
                	</rule>
                	<!--comment -->
                </grammar>
              
                                """;


    @Test
    public void getAllUid() throws Exception {
        mockMvc.perform(get("/api/grammars/uid"))
                .andExpect(status().isOk())
                .andExpect(content().contentType(MediaType.APPLICATION_JSON))
                .andExpect(result -> assertThat( result.getResponse().getContentAsString().contains("grammar_check.xsd")).isTrue());


    }

    @Test
    public void Add() throws Exception {

        mockMvc.perform(post("/api/grammars").content(testXml2))
                .andExpect(status().isCreated())
                .andExpect(content().contentType(MediaType.TEXT_PLAIN));


    }
}
